@@ -90,16 +90,14 @@ that period is fully locked for the given employee.
 
 This module provides the following exports:
 
-=over 
-
-=item * C<lid_exists> (boolean) 
-
-=back
-
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( lid_exists );
+our @EXPORT_OK = qw( 
+    count_locks_in_tsrange
+    fetch_locks_by_eid_and_tsrange
+    lid_exists 
+);
 
 
 
@@ -219,7 +217,15 @@ BEGIN {
 }
 
 
-sub fetch_by_eid_and_tsrange {
+=head2 fetch_locks_by_eid_and_tsrange
+
+Given a L<DBIx::Connector> object, an EID, and a tsrange, returns a status
+object. Upon successfully finding one or more locks, the payload will 
+be an ARRAYREF of lock records.
+
+=cut
+
+sub fetch_locks_by_eid_and_tsrange {
     my ( $conn, $eid, $tsrange ) = validate_pos( @_,
         { isa => 'DBIx::Connector' },
         { type => SCALAR },
@@ -235,6 +241,34 @@ sub fetch_by_eid_and_tsrange {
 }
 
 
+=head2 count_locks_in_tsrange
+
+Given a L<DBIx::Connector> object, an EID, and a tsrange, returns a status 
+object. If the level is OK, the payload can be expected to contain an integer
+representing the number of locks that overlap (contain points in common) with
+this tsrange.
+
+=cut
+
+sub count_locks_in_tsrange {
+    my ( $conn, $eid, $tsrange ) = validate_pos( @_,
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+        { type => SCALAR, optional => 1 },
+    );
+
+    my $status = fetch_locks_by_eid_and_tsrange( $conn, $eid, $tsrange );
+    if ( $status->ok ) {
+        my $count = @{ $status->payload };
+        return $CELL->status_ok( "DOCHAZKA_NUMBER_OF_LOCKS", payload => $count );
+    }
+    if ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
+        return $CELL->status_ok( "DOCHAZKA_NUMBER_OF_LOCKS", payload => 0 );
+    }
+    return $status;
+}
+
+
 =head1 AUTHOR
 
 Nathan Cutler, C<< <presnypreklad@gmail.com> >>
