@@ -39,7 +39,9 @@ use App::CELL qw( $CELL $log $meta $site );
 use App::Dochazka::REST::ConnBank qw( $dbix_conn );
 use App::Dochazka::REST::Model::Employee;
 use App::Dochazka::REST::Model::Shared qw(
-    load_multiple
+    cud_generic
+    select_set_of_single_scalar_rows
+    select_single
     split_tsrange
 );
 use App::Dochazka::REST::Util::Date qw(
@@ -49,7 +51,7 @@ use App::Dochazka::REST::Util::Date qw(
 );
 use App::Dochazka::REST::Util::Holiday qw(
     get_tomorrow
-    holidays_and_weekends
+    holidays_in_daterange
 );
 use Data::Dumper;
 use Date::Calc qw(
@@ -96,20 +98,32 @@ App::Dochazka::REST::Model::Tempintvls - object class for "scratch schedules"
 =head1 METHODS
 
 
-=head2 populate
+=head2 tiid
 
-Populate the tempintvls object (called automatically by 'reset' method
-which is, in turn, called automatically by 'spawn')
+If tiid attribute has been populated, return it. If it hasn't been,
+populate it and return it.
 
 =cut
 
-sub populate {
+sub tiid {
     my $self = shift;
 
-    my $ss = _next_tiid();
-    $log->debug( "Got next TIID: $ss" );
-    $self->{'tiid'} = $ss;
-    return;
+    if ( ! exists( $self->{'tiid'} ) or ! defined( $self->{'tiid'} ) or $self->{'tiid'} == 0 ) {
+        my $ss = _next_tiid();
+        $log->info( "Got next TIID: $ss" );
+        $self->{'tiid'} = $ss;
+    }
+    return $self->{'tiid'};
+}
+
+
+=head2 tiid_next
+
+=cut
+
+sub tiid_next {
+
+    return _next_tiid();
 }
 
 
@@ -184,21 +198,36 @@ sub _vet_employee {
     my $self = shift;
     my ( %ARGS ) = validate( @_, {
         dbix_conn => { isa => 'DBIx::Connector' },
-        eid => { type => SCALAR },
+        eid => { type => SCALAR|UNDEF, optional => 1 },
+        emp_obj => { 
+            type => HASHREF|UNDEF, 
+            isa => 'App::Dochazka::REST::Model::Employee', 
+            optional => 1 
+        },
     } );
     my $status;
 
-    # load employee object from database into $self->{emp_obj}
-    $status = App::Dochazka::REST::Model::Employee->load_by_eid( $ARGS{dbix_conn}, $ARGS{eid} );
-    if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
-        # all green
-        $self->{'emp_obj'} = $status->payload;
-        $self->eid( $status->payload->eid );
-    } elsif ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
-        # non-existent employee
-        return $CELL->status_err( 'DOCHAZKA_EMPLOYEE_EID_NOT_EXIST', args => [ $ARGS{eid} ] );
+    if ( exists( $ARGS{emp_obj} ) and defined( $ARGS{emp_obj} ) ) {
+        # emp_obj is provided
+        die 'AKLDWW###$$%AAAAAH!' unless $ARGS{emp_obj}->eid;
+        $self->{'emp_obj'} = $ARGS{emp_obj};
+        $self->{'eid'} = $ARGS{emp_obj}->eid;
     } else {
-        return $status;
+        # load employee object from database into $self->{emp_obj}
+        $status = App::Dochazka::REST::Model::Employee->load_by_eid( 
+            $ARGS{dbix_conn}, 
+            $ARGS{eid} 
+        );
+        if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
+            # all green
+            $self->{'emp_obj'} = $status->payload;
+            $self->{'eid'} = $ARGS{eid};
+        } elsif ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
+            # non-existent employee
+            return $CELL->status_err( 'DOCHAZKA_EMPLOYEE_EID_NOT_EXIST', args => [ $ARGS{eid} ] );
+        } else {
+            return $status;
+        }
     }
 
     # check for priv and schedule changes during the tsrange
@@ -253,13 +282,13 @@ sub _vet_activity {
     } );
     my $status;
 
-    if ( $ARGS{aid} ) {
+    if ( exists( $ARGS{aid} ) and defined( $ARGS{aid} ) ) {
         # load activity object from database into $self->{act_obj}
         $status = App::Dochazka::REST::Model::Activity->load_by_aid( $ARGS{dbix_conn}, $ARGS{aid} );
         if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
             # all green; fall thru to success
             $self->{'act_obj'} = $status->payload;
-            $self->aid( $status->payload->aid );
+            $self->{'aid'} = $status->payload->aid;
         } elsif ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
             # non-existent activity
             return $CELL->status_err( 'DOCHAZKA_GENERIC_NOT_EXIST', args => [ 'activity', 'AID', $ARGS{aid} ] );
@@ -272,7 +301,7 @@ sub _vet_activity {
         if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
             # all green; fall thru to success
             $self->{'act_obj'} = $status->payload;
-            $self->aid( $status->payload->aid );
+            $self->{'aid'} = $status->payload->aid;
         } elsif ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
             return $CELL->status_err( 'DOCHAZKA_GENERIC_NOT_EXIST', args => [ 'activity', 'code', 'WORK' ] );
         } else {
@@ -296,8 +325,13 @@ sub vet {
     my ( %ARGS ) = validate( @_, {
         dbix_conn => { isa => 'DBIx::Connector' },
         tsrange => { type => SCALAR },
-        eid => { type => SCALAR },
         aid => { type => SCALAR|UNDEF, optional => 1 },
+        eid => { type => SCALAR|UNDEF, optional => 1 },
+        emp_obj => { 
+            type => HASHREF|UNDEF, 
+            isa => 'App::Dochazka::REST::Model::Employee', 
+            optional => 1 
+        },
     } );
     my $status;
 
@@ -326,9 +360,9 @@ sub vetted {
         $self->{'vetted'}->{'tsrange'} and 
         $self->{'tsrange'} and
         $self->{'vetted'}->{'employee'} and 
-        $self->eid and
+        $self->{'eid'} and
         $self->{'vetted'}->{'activity'} and
-        $self->aid
+        $self->{'aid'}
     ) ? 1 : 0;
 }
 
@@ -352,13 +386,12 @@ sub fillup {
     my $self = shift;
     my ( %ARGS ) = validate( @_, {
         dbix_conn => { isa => 'DBIx::Connector' },
-        include_holidays => { type => SCALAR, default => 0 },
     } );
     my $status;
 
     my $rest_sched_hash_lower = _init_lower_sched_hash( $self->{sched_obj}->schedule );
 
-    my $holidays_and_weekends = holidays_and_weekends(
+    my $holidays = holidays_in_daterange(
         'begin' => $self->{lower_canon},
         'end' => $self->{upper_canon},
     );
@@ -372,17 +405,12 @@ sub fillup {
 
             # the next sequence value is already in $self->tiid
             $sth->bind_param( 1, $self->tiid );
-            $sth->bind_param( 2, $self->eid );
-            $sth->bind_param( 3, $self->aid );
 
             # execute SQL_TEMPINTVLS_INSERT for each fillup interval
             my $d = $self->{'lower_canon'};
             my $canon_upper = Date_to_Days( @{ $self->{upper_ymd} } );
             WHILE_LOOP: while ( $d ne get_tomorrow( $self->{'upper_canon'} ) ) {
-                if ( $holidays_and_weekends->{ $d }->{'weekend'} or
-                     ( $holidays_and_weekends->{ $d }->{'holiday'} and 
-                       ! $ARGS{'include_holidays'} ) 
-                    ) {
+                if ( exists $holidays->{ $d } ) {
                     $d = get_tomorrow( $d );
                     next WHILE_LOOP;
                 }
@@ -400,7 +428,7 @@ sub fillup {
                         ( $hy, $hm, $hd ) = Days_to_Date( $canon_high_dow );
                         my $payl = "[ " . ymd_to_canon( $ly,$lm,$ld ) . " " . $entry->{'low_time'} . 
                                    ", " . ymd_to_canon( $hy,$hm,$hd ) . " ". $entry->{'high_time'} . " )";
-                        $sth->bind_param( 4, $payl );
+                        $sth->bind_param( 2, $payl );
                         $sth->execute;
                         push @$intvls, $payl;
                     }
@@ -412,8 +440,6 @@ sub fillup {
                 'DOCHAZKA_TEMPINTVLS_INSERT_OK', 
                 payload => {
                     intervals => $intvls,
-                    aid => $self->aid,
-                    eid => $self->eid,
                     tiid => $self->tiid,
                 }
             );
@@ -437,8 +463,13 @@ sub new {
     my ( %ARGS ) = validate( @_, {
         dbix_conn => { isa => 'DBIx::Connector' },
         tsrange => { type => SCALAR },
-        eid => { type => SCALAR },
         aid => { type => SCALAR|UNDEF, optional => 1 },
+        eid => { type => SCALAR|UNDEF, optional => 1 },
+        emp_obj => { 
+            type => HASHREF|UNDEF, 
+            isa => 'App::Dochazka::REST::Model::Employee', 
+            optional => 1 
+        },
     } );
     my $status;
 
@@ -457,6 +488,30 @@ sub new {
 }
 
 
+=head2 dump
+
+Takes a PARAMHASH containing a C<DBIx::Connector> object and a C<tiid> 
+property. Returns all intervals matching that C<tiid>.
+
+=cut
+
+sub dump {
+    my $self = shift;
+    my ( %ARGS ) = validate( @_, {
+        dbix_conn => { isa => 'DBIx::Connector' },
+        tiid => { type => SCALAR },
+    } );
+    my $status;
+
+    $status = select_set_of_single_scalar_rows(
+        conn => $ARGS{dbix_conn},
+        sql => $site->SQL_TEMPINTVLS_SELECT,
+        keys => [ $ARGS{tiid} ],
+    );
+    return $status;
+}
+
+
 =head2 commit
 
 Takes a PARAMHASH containing a C<DBIx::Connector> object and, optionally, a
@@ -479,17 +534,37 @@ sub commit {
         dry_run => { type => SCALAR, default => 0 },
     } );
     my $status;
+    my $tiid_next = $self->tiid_next;
 
     my $sql = $ARGS{dry_run}
         ? $site->SQL_TEMPINTVLS_SELECT_EXCLUSIVE
         : $site->SQL_TEMPINTVLS_SELECT_EXCLUSIVE; # FIXME
 
-    return load_multiple(
+    $log->info( "commit tiid=" . $self->tiid . " tiid_next=$tiid_next" );
+    $status = cud_generic(
         conn => $ARGS{dbix_conn},
-        class => 'App::Dochazka::REST::Model::Interval',
-        sql => $sql,
-        keys => [ $self->{tsrange} ],
+        eid => $self->{eid},
+        sql => $site->SQL_TEMPINTVLS_COMMIT,
+        bind_params => [ 
+            "$tiid_next", $self->tiid, $self->{tsrange},
+            "$tiid_next", $self->tiid, $self->{tsrange},
+            "$tiid_next", $self->tiid, $self->{tsrange},
+        ],
     );
+    return $status unless $status->ok;
+    my $count = $status->payload;
+
+    if ( $ARGS{dry_run} ) {
+        $status = select_set_of_single_scalar_rows(
+            conn => $ARGS{dbix_conn},
+            sql => $site->SQL_TEMPINTVLS_SELECT_COMMITTED,
+            keys => [ $tiid_next ],
+        );
+        return $status;
+    }
+
+    # write attendance intervals to database
+    return $CELL->status_ok( 'SUCCESS', count => $count );
 }
 
 
